StaticKey

Enum StaticKey 

#[repr(u8)]
pub enum StaticKey {
Show 31 variants msg = 0, err = 1, error = 2, cause = 3, method = 4, status = 5, size = 6, time = 7, count = 8, total = 9, ms = 10, id = 11, user_id = 12, object_id = 13, caller = 14, target = 15, duration = 16, timezone = 17, content_type = 18, conn_id = 19, path = 20, length = 21, on = 22, kind = 23, sensor_id = 24, handler = 25, timestamp = 26, elapsed = 27, camera_id = 28, system_id = 29, next = 30,
}
Predefined field keys that use compact single-byte encoding.

These commonly used keys are encoded as a single byte rather than a length-prefixed string, reducing log size for frequent fields.

Variants



msg = 0



err = 1



error = 2



cause = 3



method = 4



status = 5



size = 6



time = 7



count = 8



total = 9



ms = 10



id = 11



user_id = 12



object_id = 13



caller = 14



target = 15



duration = 16



timezone = 17



content_type = 18



conn_id = 19



path = 20



length = 21



on = 22



kind = 23



sensor_id = 24



handler = 25



timestamp = 26



elapsed = 27



camera_id = 28



system_id = 29



next = 30

Implementations

Source

impl StaticKey

pub const NAMES: &'static [&'static str]

All static key names in declaration order.

pub fn from_u8(a: u8) -> Option<StaticKey>

Converts a byte value to the corresponding static key, if valid.

pub fn get_key(&self) -> &'static str

Returns the string name of this key.

pub fn as_str(self) -> &'static str

Returns the string name of this key.

pub fn u8_to_string(byte: u8) -> Option<&'static str>

Converts a byte value to the corresponding key name, if valid.