pub struct ValueEncoder<'a> { /* private fields */ }Expand description
Encoder for writing field values into the log buffer.
This type is passed to Encode::encode_log_value_into implementations
and provides methods for encoding values using different strategies.
Implementations
Sourceimpl<'a> ValueEncoder<'a>
impl<'a> ValueEncoder<'a>
Sourcepub fn value_via_debug<T: Debug>(self, value: &T)
pub fn value_via_debug<T: Debug>(self, value: &T)
Encodes a value using its Debug implementation.
The value is formatted directly into the log buffer without intermediate allocation.
Sourcepub fn value_via_display<T: Display>(self, value: &T)
pub fn value_via_display<T: Display>(self, value: &T)
Encodes a value using its std::fmt::Display implementation.
The value is formatted directly into the log buffer without intermediate allocation.